from distutils.core import setup

setup (
	name				= 'tonydng',
	version			= '1.4.0',
	py_modules	= ['nester'],
	author			= 'Tony Nguyen',
	author_email	= 'tonydng@gmail.com',
	url						= 'http://www.tonydng.com',
	description		= 'A simple printer of nested list',
)